@@ -1,6 +1,7 @@
-
 package Bio::MLST::FilterAlleles;
-$Bio::MLST::FilterAlleles::VERSION = '2.1.1534813';
+# ABSTRACT: Filter Alleles
+$Bio::MLST::FilterAlleles::VERSION = '2.1.1630713';
+
 use strict;
 use warnings;
 
@@ -48,18 +49,16 @@ __END__
 
 =head1 NAME
 
-Bio::MLST::FilterAlleles
+Bio::MLST::FilterAlleles - Filter Alleles
 
 =head1 VERSION
 
-version 2.1.1534813
+version 2.1.1630713
 
-=head NAME
+=head1 SYNOPSIS
 
 FilterAlleles.pm - Filter header row  from profile to remove non-alleles
 
-=head 1 SYNOPSIS
-
 =head1 AUTHOR
 
 Andrew J. Page <ap13@sanger.ac.uk>
