@@ -1,6 +1,6 @@
 package Bio::MLST::OutputFasta;
 # ABSTRACT: Take in two hashes, both containing sequence names and sequences and output fasta files.
-$Bio::MLST::OutputFasta::VERSION = '2.1.1534813';
+$Bio::MLST::OutputFasta::VERSION = '2.1.1630713';
 
 
 use Moose;
@@ -29,7 +29,9 @@ sub _build__fasta_filename
 sub _sort_and_join_sequences
 {
   my($self, $combined_sequences) = @_;
-  join("",sort(values(%{$combined_sequences})));
+  my @allele_names = sort keys %{$combined_sequences};
+  my @sorted_sequences = map { $combined_sequences->{$_} } @allele_names;
+  join("", @sorted_sequences);
 }
 
 sub create_files
@@ -93,7 +95,7 @@ Bio::MLST::OutputFasta - Take in two hashes, both containing sequence names and
 
 =head1 VERSION
 
-version 2.1.1534813
+version 2.1.1630713
 
 =head1 SYNOPSIS
 
